@@ -1,6 +1,17 @@
 import helpers
 
 class EndpointAddress(str):
+    """
+    A valid network address for one of the components of the pipeline pattern to either bind to or connect to.
+
+    The supported protocols are:
+        - tcp for cross-machine communication
+        - ipc for cross-process communication
+        - inproc for cross-thread communication
+
+    Note that on unix systems cross-process sockets are files, as it recommended to specify the .ipc file extension
+    when naming ipc socket addresses.
+    """
     def __init__(self, address):
         self.name = None
         if not helpers.valid_endpoint(self):
@@ -30,6 +41,12 @@ class BaseEnum(str):
 
 
 class TaskType(BaseEnum):
+    """
+    Represents a task type.
+
+    A task type is any valid string that has been previously registered with the TaskType class.
+    Unregistered task types will raise an exception.
+    """
     ALL_TASK_TYPES = set()
 
     @classmethod
